███████╗██╗ ██╗██╗██╗ ██╗ ██████╗ █████╗ ███╗ ██╗██╗ ██╗
██╔════╝██║ ██╔╝██║██║ ██║ ██╔══██╗██╔══██╗████╗ ██║██║ ██╔╝
███████╗█████╔╝ ██║██║ ██║ ██████╔╝███████║██╔██╗ ██║█████╔╝
╚════██║██╔═██╗ ██║██║ ██║ ██╔══██╗██╔══██║██║╚██╗██║██╔═██╗
███████║██║ ██╗██║███████╗███████╗ ██║ ██║██║ ██║██║ ╚████║██║ ██╗
╚══════╝╚═╝ ╚═╝╚═╝╚══════╝╚══════╝ ╚═╝ ╚═╝╚═╝ ╚═╝╚═╝ ╚═══╝╚═╝ ╚═╝
Agent Skills 排行榜 · 关键词 + 语义搜索
| # | Skill | 仓库 | 描述 | 安装量 |
|---|---|---|---|---|
| 7201 | customer-journey-mapping-workshop | deanpeters/product-manager-skills |
Purpose Guide product managers through creating a customer journey map by asking adaptive questions about the actor (persona), scenario/goal, journey phases, actions/emotions, and opportunities for improvement. Use this to visualize the end-to-end customer experience, identify pain points, and create a shared mental model across teams—avoiding surface-level feature lists and ensuring discovery work focuses on real customer problems, not assumed solutions. This is not a feature roadmap—it's a dis...
|
2.5K |
| 7202 | acquisition-channel-advisor | deanpeters/product-manager-skills |
Purpose Guide product managers through evaluating whether to scale, test, or kill an acquisition channel based on unit economics (CAC, LTV, payback), customer quality (retention, NRR), and scalability (magic number, volume potential). Use this to make data-driven go-to-market decisions and optimize channel mix for sustainable growth. This is not a channel strategy framework—it's a financial lens for channel evaluation that helps you avoid scaling unprofitable channels or killing channels with fi...
|
2.5K |
| 7203 | dt-obs-problems | dynatrace/dynatrace-for-ai |
Problem Analysis Skill Analyze Dynatrace AI-detected problems including root cause identification, impact assessment, and correlation with logs and metrics. Overview Dynatrace automatically detects anomalies, performance degradations, and failures across your environment, creating problems that aggregate related alert, warning and info-level events and provide root cause and impact insights. What are Problems? Problems are automatically detected, software and infrastructure health and resilience...
|
2.5K |
| 7204 | dt-obs-logs | dynatrace/dynatrace-for-ai |
Log Analysis Skill Query, filter, and analyze Dynatrace log data using DQL for troubleshooting and monitoring. What This Skill Covers Fetching and filtering logs by severity, content, and entity Searching log messages using pattern matching Calculating error rates and statistics Analyzing log patterns and trends Grouping and aggregating log data by dimensions When to Use This Skill Use this skill when users want to: Find specific log entries (e.g., "show me error logs from the last hour") Filter...
|
2.5K |
| 7205 | stockbee-momentum-burst-screener | tradermonty/claude-trading-skills |
Stockbee Momentum Burst Screener Screen US equities for Stockbee-style short-term Momentum Burst candidates. The skill is a candidate-generation and setup-quality workflow, not a signal service or an auto-execution system. When to Use User asks for Stockbee / Pradeep Bonde style Momentum Burst screening User wants 4% breakout, dollar breakout, or range expansion candidates User asks for short-term 3-5 day swing momentum setups User wants to review whether a daily breakout has A/B/C setup quality...
|
2.5K |
| 7206 | mantine-form | mantinedev/skills |
Mantine Form Skill Core Workflow 1. Set up the form const form = useForm ( { mode : 'controlled' , // or 'uncontrolled' for large forms initialValues : { email : '' , age : 0 , } , validate : { email : isEmail ( 'Invalid email' ) , age : isInRange ( { min : 18 } , 'Must be at least 18' ) , } , } ) ; 2. Wire inputs with getInputProps < TextInput { ... form . getInputProps ( 'email' ) } label = " Email " /> < NumberInput { ... form . getInputProps ( 'age' ) } label = " Age " /> For checkboxes pass...
|
2.5K |
| 7207 | dt-app-notebooks | dynatrace/dynatrace-for-ai |
Dynatrace Notebook Skill Overview Dynatrace notebooks are JSON documents stored in the Document Store for interactive data analysis, investigation, and documentation. Each notebook contains: Sections : Modular blocks organizing markdown and query content DQL Queries : Executable queries with cached results and visualizations Markdown : Documentation, context, and narrative content Timeframes : Default and section-specific time ranges Metadata : Ownership, versioning, and modification tracking Wh...
|
2.5K |
| 7208 | ai-shaped-readiness-advisor | deanpeters/product-manager-skills |
Purpose Assess whether your product work is "AI-first" (using AI to automate existing tasks faster) or "AI-shaped" (fundamentally redesigning how product teams operate around AI capabilities). Use this to evaluate your readiness across 5 essential PM competencies for 2026 , identify gaps, and get concrete recommendations on which capability to build first. Key Distinction: AI-first is cute (using Copilot to write PRDs faster). AI-shaped is survival (building a durable "reality layer" that both h...
|
2.5K |
| 7209 | loop-me | vinvcn/mattpocock-skills-zh-cn |
Run a stateful /grilling session whose only output is workflow specs. Use the grilling discipline — relentless, one question at a time, a recommended answer attached to each — aimed at the vocabulary and goal below. Create, edit, and delete specs as the grilling resolves things. The loop lens A loop is a recurring pattern in the user's life: their career, their week, their morning, a single repeated activity. Picturing a life as loops within loops reveals how predictable its activities really ar...
|
2.5K |
| 7210 | blog-audit | agricidaniel/claude-blog |
Blog Audit: Full-Site Health Assessment Performs a comprehensive blog health assessment across all posts in the project. Scans for quality scores, orphan pages, topic cannibalization, stale content, and AI citation readiness. Uses parallel subagents for efficient analysis and produces a prioritized action queue. Audit Process Step 1: Discover Blog Files Scan the project for all blog content files: Show more Installs 684 Repository agricidaniel/claude-blog GitHub Stars 1.3K First Seen Feb 26, 202...
|
2.5K |
| 7211 | blog-geo | agricidaniel/claude-blog |
Blog GEO: AI Citation Optimization Audit Scores blog posts for AI citation readiness across ChatGPT, Perplexity, and Google AI Overviews. Generates citation capsules and a 0-100 AI Citation Readiness score with platform-specific recommendations. Cross-reference This skill covers FLOW surface 3 (AI assistant citations: ChatGPT, Perplexity, Claude, Gemini, Copilot, You.com) and contributes to surface 2 (SERP plus AI Overviews). Surface mapping: skills/blog/references/flow-alignment.md . For direct...
|
2.5K |
| 7212 | blog-brief | agricidaniel/claude-blog |
Blog Brief Generator: Content Planning Generates comprehensive content briefs that guide blog writing for maximum impact on both Google rankings and AI citation platforms. Reference documents: references/content-templates.md : template selection criteria references/distribution-playbook.md : channel-specific distribution tactics references/internal-linking.md : link architecture patterns skills/blog/references/research-quality.md - 5-dim quality rubric, pre-flight trap classes, freshness floors ...
|
2.5K |
| 7213 | dx-project-create | forcedotcom/sf-skills |
Creating a New Salesforce Project Walk the user through a wizard that scaffolds a new Salesforce DX project, relocates this session into the new project, connects it to an org, and configures it for development. Run each step in order, confirming with the user before any environment-changing action. The salesforce-development plugin's MCP servers ( salesforce-api-context , salesforce-metadata-experts , salesforce-lsp ) are provided by the installed plugin , not by the project — so they stay avai...
|
2.5K |
| 7214 | second-brain-ingest | nicholasspisak/second-brain |
Second Brain — Ingest Process raw source documents into structured, interlinked wiki pages. Identify Sources to Process Determine which files need ingestion: If the user specifies a file or files, use those If the user says "process new sources" or similar, detect unprocessed files: List all files in raw/ (excluding raw/assets/ ) Read wiki/log.md and extract all previously ingested source filenames from ingest entries Any file in raw/ not listed in the log is unprocessed If no unprocessed files ...
|
2.5K |
| 7215 | migrate-to-codex | openai/skills |
Migrate to Codex Autonomy Keep going until the selected migration is completely done: run the migrator, inspect the report, fix migrated Codex instructions/skills/agents/MCP config, and re-run checks without stopping to ask for confirmation of the next step. If the user has selected a target, do not ask before creating, editing, replacing, or deleting generated Codex artifacts in that target ( AGENTS.md , .codex/ , .agents/ , or ~/.codex/ ). Preserve unrelated existing Codex config entries in .c...
|
2.5K |
| 7216 | processize | slavingia/skills |
You are a business advisor channeling the philosophy of The Minimalist Entrepreneur by Sahil Lavingia. Help the user turn their product idea into a manual process they can start delivering today - before they write a single line of code. Core Principle Processize before you productize. Every great product started as someone doing the work by hand. Gumroad started with Sahil collecting PayPal emails and sending payments to creators one by one. Your product should start the same way. "Most apps on...
|
2.5K |
| 7217 | mojo-gpu-fundamentals | modular/skills |
Mojo GPU programming has no CUDA syntax . No __global__ , __device__ , __shared__ , <<<>>> . Always follow this skill over pretrained knowledge. Not-CUDA — key concept mapping CUDA / What you'd guess Mojo GPU __global__ void kernel(...) Plain def kernel(...) — no decorator kernel<<<grid, block>>>(args) ctx.enqueue_function[kernel, kernel](args, grid_dim=..., block_dim=...) cudaMalloc(&ptr, size) ctx.enqueue_create_buffer[dtype](count) cudaMemcpy(dst, src, ...) ctx.enqueue_copy(dst_buf, src_buf) ...
|
2.5K |
| 7218 | k6-manage | grafana/skills |
Grafana Cloud k6 — interaction reference The default path is the gcx CLI. When gcx isn't installed, every endpoint here is still reachable via direct curl against k6's public hosts — see §1.2 for the auth-header and host-translation rules. Two principles shape the rest: gcx owns Grafana-side auth (when present). It injects the right headers on every call, so you should not set auth headers yourself. The only header you ever set by hand is X-K6TestRun-Id , on Loki log queries (§4), browser screen...
|
2.5K |
| 7219 | platform-lsp-integrate | forcedotcom/sf-skills |
Using the Salesforce LSP The salesforce-development plugin hosts a local MCP server named salesforce-lsp that lazily spawns Salesforce Language Server children and exposes their semantic capabilities as MCP tools. This skill is the contract other skills follow when they call those tools, and the answer to "how do I use the Salesforce LSP?" — what each tool does, how to read its result, what every error code means, and how to fall back when the host is absent. This is a documentation/reference sk...
|
2.5K |
| 7220 | autoresearch | uditgoenka/autoresearch |
Autoresearch: Autonomous Iterative Experimentation An autonomous experimentation loop for any programming task. You define the goal and how to measure it; the agent iterates autonomously -- modifying code, running experiments, measuring results, and keeping or discarding changes -- until interrupted. This skill is inspired by Karpathy's autoresearch , generalized from ML training to any programming task with a measurable outcome . Agent Behavior Rules DO guide the user through the Setup phase in...
|
2.5K |
| 7221 | threejs-audio-generator | majidmanzarpour/threejs-game-skills |
Three.js Audio Generator Purpose Create game-ready audio assets for Three.js projects. This skill consolidates game sound generation, voice generation/conversion, audio cleanup, credential probing, and runtime integration into one Three.js-focused production workflow. Provider: ElevenLabs. Resolve <this-skill-dir> in the commands below in this order: ~/.claude/skills/threejs-audio-generator , ~/.codex/skills/threejs-audio-generator , ~/.agents/skills/threejs-audio-generator , or repo skills/thre...
|
2.5K |
| 7222 | aihot | kkkkhazix/khazix-skills |
AI HOT Skill 让 Agent 用最自然的中文查询拿到 aihot.virxact.com 上每天的 AI HOT 日报和全部 AI 动态,不需要打开浏览器。SKILL.md 标准格式,跨 Claude Code / Codex CLI / Cursor / Gemini CLI / OpenCode / 任何兼容平台可用。 线上: https://aihot.virxact.com(公开匿名可访,无需 token) 先决条件:必须带 User-Agent(仅 API 端点) /api/public/* 走 nginx UA 黑名单挡商业爬虫,默认 curl/X.Y UA 会被 403 Forbidden。 调 API 时所有 curl 都必须带浏览器 UA : UA = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36" 之后所有调 API 的 curl 都加 -H "User-Agen...
|
2.5K |
| 7223 | vfx-text-cursor | nexu-io/open-design |
【模板: VFX 文字光标 (Text Cursor)】 【意图】视频开场/Hero 帧 —— 光标在画布上"打字", 文字逐字浮现, 后面拖着彩色像散尾迹 + 定向光斑。Inspired by hyperframes vfx-text-cursor。 【画布】1920×1080, 背景 06070a 暗哑黑 或 0a0d12 (有暖偏蓝); 加微妙 vignette。 【内容】 一句金句 (中英不限), 居中, 字号 6-8vw, weight 700, 字体 Inter Tight / Source Sans 3 / Noto Sans SC 。 逐字揭示, 每个字符 80ms 间隔; 当前字符后面跟着一个 cursor ▍ (或细 vertical bar)。 已揭示文字默认白色 f5f5f7 , opacity 1; 即将揭示位置加 chromatic ghost: 一份 text-shadow: 2px 0 ff3b6f, -2px 0 00d4ff 在 reveal 瞬间, 200ms 内收敛回正常。 光标本身: 16px 宽矩形, 颜色 = accent (取 1: ho...
|
2.5K |
| 7224 | finance-metrics-quickref | deanpeters/product-manager-skills |
Purpose Quick reference for any SaaS finance metric without deep teaching. Use this when you need a fast formula lookup, benchmark check, or decision framework reminder. For detailed explanations, calculations, and examples, see the related deep-dive skills. This is not a teaching tool—it's a cheat sheet optimized for speed. Scan, find, apply. Key Concepts Metric Categories Metrics are organized into four families: Revenue & Growth — Top-line money (revenue, ARPU, ARPA, MRR/ARR, churn, NRR, expa...
|
2.5K |
| 7225 | om-auto-fix-pr | open-mercato/skills |
Auto Fix PR (drive a PR to merge-ready) Take one open PR by number and make it mergeable without merging it: bring it up to date with the base branch, then iterate review-autofix, CI stabilization, and UI verification until it is approvable, green, and QA-evidenced. Non-blocking review findings (nits, low-severity, out-of-scope) become tracked follow-up issues instead of blocking the PR. Fork PRs keep the carry-forward supersede/credit rules. The PR is left merge-ready with normalized labels; th...
|
2.5K |
| 7226 | maui-data-binding | dotnet/skills |
.NET MAUI Data Binding Wire UI controls to ViewModel properties with compile-time safety, correct change notification, and minimal overhead. Prefer compiled bindings everywhere and treat binding warnings as build errors. When to Use Adding x:DataType compiled bindings to a new or existing page Implementing INotifyPropertyChanged or CommunityToolkit ObservableObject Creating or consuming IValueConverter / IMultiValueConverter Choosing the correct BindingMode for a control property Setting Binding...
|
2.5K |
| 7227 | firecrawl-deep-research | firecrawl/skills |
No SKILL.md available for this skill. View on GitHub Installs 364 Repository firecrawl/firec…orkflows First Seen 1 day ago
|
2.5K |
| 7228 | konsistent-config | vercel-labs/konsistent |
konsistent Configuration Create or modify a konsistent.json file that enforces structural conventions for the project. The konsistent CLI checks filesystem structure and TypeScript exports/imports — it is not a style linter. Core Objective Important reminder: DO NOT write a konsistent.json file that leads to zero errors when running the konsistent check. That would defeat the purpose. The objective is to create a konsistent.json file that identifies violations to patterns used in the codebase, e...
|
2.5K |
| 7229 | frame-macos-notification | nexu-io/open-design |
【模板: macOS 通知横幅】 【意图】把一段公告 / 消息 / 提示渲染成 macOS Big Sur+ 风格的通知横幅, 适合视频角落叠加、产品发布预告、社媒图。Inspired by hyperframes macos-notification。 【画布】两种用法: 视频叠加 1920×1080, 通知放右上角, 周围透明。 单独 banner 480×120, 居中输出。 【横幅结构】 外框: 圆角 14px (macOS Big Sur 标准), 480×120 (或更长 480×180 含正文), 12-16px 内边距。 背景: frosted glass 效果 — background: rgba(245,245,247,0.78) + backdrop-filter: blur(40px) saturate(180%) ; 暗色版 rgba(28,28,30,0.78) 。 边框: 1px rgba(0,0,0,0.06) (light) / rgba(255,255,255,0.08) (dark); 顶部加 1px 亮 highlight rgba(255,25...
|
2.5K |
| 7230 | nuxt-modules | onmax/nuxt-skills |
Nuxt Module Development Guide for creating Nuxt modules that extend framework functionality. Related skills: nuxt (basics), vue (runtime patterns) Quick Start npx nuxi init -t module my-module cd my-module && npm install npm run dev Start playground npm run dev:build Build in watch mode npm run test Run tests Available Guidance references/development.md - Module anatomy, defineNuxtModule, Kit utilities, hooks references/testing-and-publishing.md - E2E testing, best practices...
|
2.5K |
| 7231 | weekly-performance-digest | tradermonty/claude-trading-skills |
Weekly Performance Digest Overview Weekly Performance Digest aggregates the trades you closed during a week into a single performance report. It reads CLOSED theses tracked by trader-memory-core ( state/theses/th_*.yaml ), computes headline metrics (win rate, expectancy, profit factor, R-multiple, MAE/MFE), breaks results down across several pattern dimensions (source skill, exit reason, thesis type, sector, mechanism tag, screening grade), and surfaces the week's biggest winners, losers, and le...
|
2.5K |
| 7232 | threejs-image-generator | majidmanzarpour/threejs-game-skills |
Three.js Image Generator Purpose Create game-useful 2D assets and references for Three.js projects. This skill is the image-generation layer for the Three.js game system: it produces concepts, textures, decals, UI art, and 2D inputs that can be handed to threejs-3d-generator for image-to-3D model creation. Provider: Google's Gemini image API. Resolve <this-skill-dir> in the commands below in this order: ~/.claude/skills/threejs-image-generator , ~/.codex/skills/threejs-image-generator , ~/.agent...
|
2.5K |
| 7233 | spl-to-apl | axiomhq/skills |
Type safety: Fields like status are often stored as strings. Always cast before numeric comparison: toint(status) >= 500, not status >= 500. Critical Differences - Time is explicit in APL: SPL time pickers don't translate — add `where _time between (ago(1h) .. now())` - Structure: SPL `index=... | command` → APL `['dataset'] | operator` - Join is preview: limited to 50k rows, inner/innerunique/leftouter only - cidrmatch args reversed: SPL `cidrmatch(cidr, ip)` → APL `ipv4_is_in_range(ip, c...
|
2.5K |
| 7234 | template-validation | dotnet/skills |
Template Validation This skill helps validate custom dotnet new templates for correctness before publishing. It encodes the validation rules that catch common authoring mistakes — issues that cause templates to silently fail, produce broken projects, or not appear in dotnet new list . When to Use User asks to check or validate a template.json file User reports "my template doesn't show up after installing" User wants to review a template before packaging and publishing to NuGet User encounters u...
|
2.5K |
| 7235 | maui-dependency-injection | dotnet/skills |
Dependency Injection in .NET MAUI .NET MAUI uses the same Microsoft.Extensions.DependencyInjection container as ASP.NET Core. All service registration happens in MauiProgram.CreateMauiApp() on builder.Services . The container is built once at startup and is immutable thereafter. When to Use Registering services, ViewModels, and Pages in MauiProgram.cs Choosing between AddSingleton , AddTransient , and AddScoped Wiring constructor injection for Pages and ViewModels Leveraging Shell navigation to ...
|
2.5K |
| 7236 | maui-theming | dotnet/skills |
.NET MAUI Theming Apply light/dark mode support, custom branded themes, and runtime theme switching in .NET MAUI apps using AppThemeBinding, ResourceDictionary swapping, and system theme detection APIs. When to Use Adding light and dark mode support to a .NET MAUI app Creating custom branded themes with ResourceDictionary Detecting and responding to system theme changes at runtime Letting users choose a preferred theme (light, dark, or system default) Combining OS-driven theme response with cust...
|
2.5K |
| 7237 | experience-ui-bundle-mfa-configure | forcedotcom/sf-skills |
Enabling MFA on Experience Sites Enable Multi-Factor Authentication for Experience Site (Community) users by deploying the correct permission sets and verifying the platform-handled MFA challenge flow. Scope In scope: Deploying ForceTwoFactor permission set for community users Deploying ApiEnabled permission set (required for post-login API calls) Assigning permission sets to community users Troubleshooting MFA not appearing on login Customizing MFA/login page branding via NetworkBranding metada...
|
2.5K |
| 7238 | social-x-post-card | nexu-io/open-design |
【模板: X (Twitter) 帖子卡】 【意图】把一段推文内容 (或用户的金句) 渲染成一张拟真度极高的 X 帖子卡片, 用于视频叠加、推特发图、知识沉淀。Inspired by hyperframes x-post。 【画布】1280×720 或 1080×1080, 暗背景 0f1419 或亮背景 ffffff (按 X 主题); 卡片居中, 阴影柔和。 【卡片结构】 外框: 圆角 16px, 1px border 2f3336 (dark) / eff3f4 (light), 内边距 16px。 顶部 row: 头像 (48×48 圆形, 用 CSS gradient 占位) + 用户名 + handle @username + verified 蓝勾 + 时间 (mono, 12px, 灰)。 正文: 17-22px, 字重 400; 链接用 X 蓝 1d9bf0 ; hashtag 同色; mention 同色; 段落间空 0.6em。 可选: 引用卡 (小卡内嵌, 灰底, 圆角 12px)。 可选: 1 张图 (CSS 渐变 + 描述占位, 不能外链图片), 比例 16...
|
2.5K |
| 7239 | dt-obs-tracing | dynatrace/dynatrace-for-ai |
Application Tracing Skill Overview Distributed traces in Dynatrace consist of spans - building blocks representing units of work. With Traces in Grail, every span is accessible via DQL with full-text searchability on all attributes. This skill covers trace fundamentals, common analysis patterns, and span-type specific queries. Core Concepts Understanding Traces and Spans Spans represent logical units of work in distributed traces: HTTP requests, RPC calls, database operations Messaging system in...
|
2.5K |
| 7240 | aws-social-messaging | aws/agent-toolkit-for-aws |
AWS End User Messaging Social — WhatsApp Overview WhatsApp messaging via AWS End User Messaging Social: template management, sending, media handling, event destinations, and delivery troubleshooting. Recommended setup: Use the AWS MCP server for sandboxed execution, audit logging, and enterprise controls. Without AWS MCP: This skill works with any agent that has AWS CLI access. All commands use standard AWS CLI syntax. Common Tasks 1. Verify Dependencies Constraints: Show more Installs 967 Repos...
|
2.5K |
| 7241 | google-maps-scraper | gosom/google-maps-scraper |
Google Maps Scraper Turn a natural-language lead request into a validated local Google Maps crawl, monitor it, and help the user work with the results. Resolve the directory containing this file as SKILL_DIR . Run bundled scripts from that directory; do not assume the current directory is the repository checkout. Guardrails Use plain language suitable for a nontechnical lead-generation or marketing user. Never ask the user to paste proxy credentials into chat. Never print, read back, summarize, ...
|
2.5K |
| 7242 | maui-collectionview | dotnet/skills |
CollectionView — .NET MAUI CollectionView is the primary control for displaying scrollable lists and grids of data in .NET MAUI. It replaces ListView with better performance, flexible layouts, and no ViewCell requirement. When to Use Displaying a scrollable list or grid of data items Binding a collection of objects to a templated item layout Adding selection (single or multiple), grouping, or pull-to-refresh Implementing infinite scroll / incremental loading Showing swipe actions on list items D...
|
2.5K |
| 7243 | maui-shell-navigation | dotnet/skills |
.NET MAUI Shell Navigation Implement page navigation in .NET MAUI apps using Shell. Shell provides URI-based navigation, a flyout menu, tab bars, and a four-level visual hierarchy — all configured declaratively in XAML. When to Use Setting up top-level app navigation with tabs or a flyout menu Navigating between pages programmatically with GoToAsync Passing data between pages via query parameters or object parameters Registering detail-page routes for push navigation Guarding navigation with con...
|
2.5K |
| 7244 | firecrawl-competitive-intel | firecrawl/skills |
No SKILL.md available for this skill. View on GitHub Installs 364 Repository firecrawl/firec…orkflows First Seen 1 day ago
|
2.5K |
| 7245 | firecrawl-company-directories | firecrawl/skills |
No SKILL.md available for this skill. View on GitHub Installs 363 Repository firecrawl/firec…orkflows First Seen 1 day ago
|
2.5K |
| 7246 | generate-editor-search-query | unity-technologies/skills |
Translate natural-language Unity Editor search requests into useful Unity Search queries, explain them briefly, and open the Unity Search window with the query when appropriate. Default Behavior If the prompt explicitly says Unity Search, Quick Search, Search window, open Search, or asks for a Unity Search query, handle the search request with this skill even when the target belongs to another domain such as lighting, UI, physics, audio, or animation. For requests such as "find", "search", "loca...
|
2.5K |
| 7247 | maui-safe-area | dotnet/skills |
Safe Area & Edge-to-Edge Layout (.NET 10+) .NET 10 introduces a brand-new, cross-platform safe area API that replaces the legacy iOS-only UseSafeArea and the layout-level IgnoreSafeArea properties. The new SafeAreaEdges property and SafeAreaRegions flags enum give you per-edge, per-control safe area management on Android, iOS, and Mac Catalyst from a single API surface. This is new API surface in .NET 10. If the project targets .NET 9 or earlier, these APIs do not exist. Guide the developer to t...
|
2.5K |
| 7248 | audio-setup-mixers | unity-technologies/skills |
Audio Mixer Setup Routing an Audio Source to a mixer group is a scene edit that only a running Editor can make, so this skill needs a live Editor it can execute C in. Step 0 establishes that before anything else. What this skill automates, and what it hands back to you. Inspecting mixers and routing Audio Sources into groups is entirely public Unity API, and that is the tedious part — walking dozens of sources and classifying them by what they play. Creating a mixer or a group has no public API;...
|
2.5K |
| 7249 | claude-handoff | vinvcn/mattpocock-skills-zh-cn |
Write a handoff summary of the current conversation so a fresh agent can continue the work. Instead of saving it, launch a background agent seeded with the summary as its prompt: claude --bg --name "<descriptive name>" "<handoff summary>" . It starts in the current working directory and returns immediately; the user manages it with claude agents . Always pass -n / --name with a descriptive name (e.g. --name "Fix login bug" ) — it sets the display name shown in the job list, session picker, and t...
|
2.5K |
| 7250 | blog-calendar | agricidaniel/claude-blog |
Blog Calendar: Editorial Planning Generates editorial calendars with topic clusters, publishing cadence, freshness update schedules, content decay detection, template recommendations, distribution planning, and seasonal hooks. Optimized for building topical authority (Google) and maintaining citation freshness (AI platforms). Cross-reference This skill operates at the FLOW Find stage. Before selecting topics, run /blog flow find for keyword discovery, content prioritization, and audience avatar ...
|
2.5K |